#!/usr/bin/env python

import numpy as np
from matplotlib import pyplot as plt
import sys

DISHES = 3
IMSIZE = 1024
RADIUS1 = 32
RADIUS2 = 100

plot_rows, plot_cols = DISHES, 4
plot_shape = '%d%d' % (plot_rows, plot_cols)

def gen_aperture(imsize, radius):
	aperture = np.ones(shape=(imsize,imsize), dtype=np.complex128)
	origin = imsize/2
	for i in range(origin):
		for j in range(origin):
			if np.hypot(i,j) > radius:
				aperture[origin-i,origin-j] = 0
				aperture[origin+i,origin-j] = 0
				aperture[origin-i,origin+j] = 0
				aperture[origin+i,origin+j] = 0
	return aperture

def gen_voltage(aperture):
	return np.fft.fftshift(np.fft.fft2(np.fft.fftshift(aperture)))

def plot_dish(row, aperture, voltage):
	plt.subplot(plot_rows, plot_cols, (row-1)*plot_cols+1)
	plt.imshow(aperture.real)
	plt.subplot(plot_rows, plot_cols, (row-1)*plot_cols+2)
	plt.imshow(aperture.imag)
	plt.subplot(plot_rows, plot_cols, (row-1)*plot_cols+3)
	plt.imshow(abs(voltage))
	plt.subplot(plot_rows, plot_cols, (row-1)*plot_cols+4)
	plt.imshow(np.arctan2(voltage.imag,voltage.real))

ap1 = gen_aperture(IMSIZE, RADIUS1)
ap2 = gen_aperture(IMSIZE, RADIUS2)
vlt1 = gen_voltage(ap1)
vlt2 = gen_voltage(ap2)

vlt3 = vlt1 * vlt2
ap3 = np.fft.fftshift(np.fft.ifft2(np.fft.fftshift(vlt3)))

plot_dish(1,ap1,vlt1)
plot_dish(2,ap2,vlt2)
plot_dish(3,ap3,vlt3)

plt.show()
