#!/usr/bin/env python

import numpy as np
from matplotlib import pyplot as plt
import sys

name_list = [ '25', '76',  '32', '100']
size_list = [ 25.0, 76.0,  32.0, 100.0]
sefd_list = [300.0, 36.0, 220.0,  20.0]

def sens(i,j):
	return (sefd_list[i] * sefd_list[j]) ** 0.5

POINTS = 10000	# Number of samples
RADIUS = 5 	# Degrees, field of view to sample

wl = 0.18	# Metres, wavelength
N = 0.8 	# Constant
r = np.radians(RADIUS)
ang = np.arange(0, r, r / POINTS)

comb_beam = np.zeros(shape=ang.shape)
for i in range(len(size_list)-1):
	for j in range(i+1, len(size_list)):
		g = 1 / sens(i,j) * np.sinc(N * ang * size_list[i] / wl) * np.sinc(N * ang * size_list[j] / wl)
		plt.plot(60 * np.degrees(ang), g, label='%s - %s' % (name_list[i], name_list[j]))
		comb_beam += g ** 2
comb_beam **= 0.5
plt.plot(60 * np.degrees(ang), comb_beam, label='all')
plt.legend()
plt.show()
