#!/usr/bin/env python

import numpy as np
from matplotlib import pyplot as plt
import sys
from sched_sens import antenna_sefd_dict

imsize = 512
dish_sizes = {'Ro70': 70, 'Nl': 25, 'Jb2': 25, 'Jb1': 76, 'La': 25, 'Tr': 32, 'Pb': -1, 'Ny': 20, 'Sv': 32, 'Ro34': 34, 'Pv': -1, 'Kp': 25, 'Nt': 32, 'Tc': -1, 'Pt': 25, 'Y27': 3000, 'Bd': 32, 'Wb': 2700, 'Hh': 26, 'Hn': -1, 'Br': 32, 'Fd': 32, 'Ys': 40, 'Wz': 20, 'On': 25, 'Ka': -1, 'Mc': 32, 'Mh': 14, 'Km': 40, 'Ur': 25, 'Go': -1, 'Sh': 25, 'Mk': 25, 'Sm': -1, 'Sc': 25, 'Ov': 25, 'My': 50, 'Cm': 32, 'Ef': 100, 'Zc': 32, 'Ar': 305, 'Gb': 100, 'W1': 25, 'Y1': 25}

def comb_sefd(sefd_dict, ant_list):
	comb = 0
	for i in range(len(ant_list)-1):
		for j in range(i+1 ,len(ant_list)):
			comb += 1.0 / (sefd_dict[ant_list[i]] * sefd_dict[ant_list[j]])
	sefd_total = 1.0 / comb ** 0.5
	return sefd_total

def sens(sefd_dict, ant1, ant2):
	return (sefd_dict[ant1] * sefd_dict[ant2]) ** 0.5

POINTS = 1000	# Number of samples
RADIUS = 20.0/60	# Degrees, field of view to sample

wl = 0.18	# Metres, wavelength
N = 0.8 	# Constant
r = np.radians(RADIUS)
ang = np.arange(0, r, r / POINTS)

sefd_dict = antenna_sefd_dict(wl)
#ant_list = ['Jb1', 'Jb2', 'On', 'Tr', 'Ef', 'Kp', 'Ar']
#ant_list = ['Ef', 'Wb', 'Jb1', 'On', 'Mc', 'Tr', 'Sv', 'Zc', 'Bd', 'Ur', 'Sh', 'Hh']
ant_list = ['Ef', 'Jb1', 'On', 'Mc', 'Tr', 'Sv', 'Zc', 'Bd', 'Ur', 'Sh', 'Hh']
ant_list = ['Br', 'Fd','Hn','Kp','La','Mk','Nl','Ov','Pt','Sc']
ant_list = ['Br', 'Ef']

print comb_sefd(sefd_dict, ant_list)

def mirror(a):
	return np.concatenate((a[::-1], a))

def neg_mirror(a):
	return np.concatenate((-a[::-1], a))

plt.subplot(121)
comb_beam = np.zeros(shape=ang.shape)
for i in range(len(ant_list)-1):
	for j in range(i+1, len(ant_list)):
		g = 1 / sens(sefd_dict, ant_list[i], ant_list[j]) * np.sinc(N * ang * dish_sizes[ant_list[i]] / wl) * np.sinc(N * ang * dish_sizes[ant_list[j]] / wl)
		plt.plot(neg_mirror(60 * np.degrees(ang)), mirror(g), label='%s - %s' % (ant_list[i], ant_list[j]))
		comb_beam += g ** 2
comb_beam **= 0.5

max_a = 2 ** 0.5 * imsize
beam2d = np.empty(shape=(imsize, imsize), dtype=np.float32)
halfim = imsize / 2
for i in range(halfim):
	for j in range(halfim):
		a = (i**2 + j**2) ** 0.5
		val = comb_beam[a/max_a * POINTS]
		beam2d[halfim+i, halfim+j] = val
		beam2d[halfim-i, halfim+j] = val
		beam2d[halfim+i, halfim-j] = val
		beam2d[halfim-i, halfim-j] = val
		
plt.plot(60 * neg_mirror(np.degrees(ang)), mirror(comb_beam), label='all')
#plt.legend()
plt.subplot(122)
sq_max = RADIUS * 60 / 2 ** 0.5
plt.imshow(beam2d, extent=(-sq_max, sq_max, -sq_max, sq_max))
plt.show()
