#!/usr/bin/env ParselTongue

import AIPS
from AIPSData import AIPSUVData
from pyrap.tables import table
from pyrap.quanta import quantity
import math
import time
import sys
import shutil
import datetime
import numpy

AIPS.userno = 2
mod_jul_day = quantity(40587.0, 'd')
mod_jul_day.convert(quantity(1.0, 's')) # Modified Julien day

uv = AIPSUVData('20030703', 'LINE', 1,1)
sn = uv.table('SN', 1)
pols = sn.keywords['NO_POL']
ifs = sn.keywords['NO_IF']

shutil.copytree('empty.gcal', sys.argv[1])
gcal = table(sys.argv[1], ack=False, readonly=False)

ant_nums = []
ant = table('AG650.MS/ANTENNA', ack=False)
for row in ant:
	ant_nums.append(int(row['NAME'][-2:]))

obs_date = datetime.datetime(*[int(i) for i in uv.header.date_obs.split('-')])

gain = numpy.ones(shape=(1, pols), dtype='complex64')
total_fit = 1.0
total_fit_weight = 1.0
total_solution_ok = True 
solution_ok = numpy.ones(shape=(1,pols), dtype='bool')
fit = numpy.ones(shape=(1,1), dtype='float32')
fit_weight = numpy.ones(shape=(1,1), dtype='float32')
flag = numpy.zeros(shape=(1,pols), dtype='bool')
snr = numpy.ones(shape=(1,pols), dtype='float32')

defs = {'SOLUTION_OK': solution_ok, 'TOTAL_SOLUTION_OK': total_solution_ok,
        'TOTAL_FIT_WEIGHT': total_fit_weight, 'TOTAL_FIT': total_fit,
        'SOLUTION_OK': solution_ok, 'FIT': fit, 'FIT_WEIGHT': fit_weight,
        'FLAG': flag, 'SNR': snr, 'GAIN': gain}

gcal.addrows(len(sn))
for i in range(len(sn)):
	gcal[i] = defs
	sol_time = obs_date + datetime.timedelta(float(sn[i].time))
	time_unix = time.mktime(sol_time.timetuple())
	time_casa = time_unix + mod_jul_day.get_value()
	time_interval = quantity(sn[i].time_interval, 'd')
	time_interval.convert(quantity(1.0, 's'))
	time_interval = time_interval.get_value()
	try:
		antenna1 = ant_nums.index(sn[i].antenna_no)
	except ValueError:
		print sn[i].antenna_no, 'not in ms'
	gain = gcal[i]['GAIN']
	for p in range(pols):
		gain[0][p] = sn[i]['real%d' % (p+1)] + 1j * sn[i]['imag%d' % (p+1)]
	snr = gcal[i]['SNR']
	for p in range(pols):
		snr[0][p] = sn[i]['weight_%d' % (p+1)]
	gcal[i] = {'TIME': time_casa, 'INTERVAL': time_interval,
		   'GAIN': gain, 'SNR': snr, 'ANTENNA1': antenna1}
	gcal[i].update()
gcal.close()
