#!/usr/bin/env ParselTongue
#
# Tool to convert AIPS Calibration tables to Measurement Set Calibration tables
# Stephen Bourke, JIVE
# Version 2010.11.29

import shutil
import numpy
import os.path
from taskinit import tb

cal_base = 'casa_cl'
ms_name = 'STEVE'
chans = 1
pols = 2
ifs = 8

DOBAND = False
DOCALIB = not DOBAND

mod_jul_day = 3506716800.0

if DOBAND:
	cal_type_list = ['bcal']
else:
	cal_type_list = ['gcal', 'mbdcal', 'sbdcal']
for cal_type in cal_type_list:
	cal_table = cal_base + '.' + cal_type
	shutil.copytree('empty.' + cal_type, cal_table)	# Copy empty template table

	# Make an CAL_DESC entry for each AIPS IF
	cal_desc_defs = {'NUM_SPW': numpy.ones(shape=(ifs,), dtype='int'),
			 'NUM_CHAN': numpy.ones(shape=(chans,ifs), dtype='int'),
			 'NUM_RECEPTORS': numpy.array(ifs * [pols], dtype='int'),
			 'N_JONES': numpy.array(ifs * [2], dtype='int'),
			 'CHAN_FREQ': numpy.zeros(shape=(1,chans,ifs), dtype='float64'),
			 'MEAS_FREQ_REF': numpy.zeros(shape=(ifs,), dtype='int'),
			 'CHAN_WIDTH': numpy.zeros(shape=(1,chans,ifs), dtype='float64'),
			 'SPECTRAL_WINDOW_ID': numpy.zeros(shape=(1,ifs), dtype='int32'),
			 'CHAN_RANGE': numpy.zeros(shape=(2,1,chans,ifs), dtype='int32'),
			 'POLARIZATION_TYPE': numpy.zeros(shape=(1,chans,ifs), dtype='|S1'),
			 'JONES_TYPE': numpy.array(ifs * ['full']),
			 'MS_NAME': numpy.array(ifs * [os.path.basename(ms_name)])}
	
	tb.open(cal_table + '/CAL_DESC', nomodify=False)
	tb.addrows(ifs)
	for key, value in cal_desc_defs.items():
		tb.putcol(key, value)
	col = tb.getcol('SPECTRAL_WINDOW_ID')
	col[0] = range(ifs)
	tb.putcol('SPECTRAL_WINDOW_ID', col)
	tb.close()
