#!/usr/bin/env python

from pyrap.tables import table
from pyrap.quanta import quantity
import datetime
import sys

mod_jul_day = quantity(40587.0, 'd') # Modified Julien day

def set_unit(q, unit):
    """Set the unit type of a pyrap quantity."""
    q.convert(quantity(1.0, unit))

def get_scalar_col_unit(table, col_name):
    """Get the quantity unit of a scalar column."""
    unit = table.getcolkeyword(col_name, 'QuantumUnits')
    assert len(unit) == 1, 'Unexpected (non-scalar) data format'
    return unit[0]

def get_observation_time(msname):
	"""Return unix time of the observation. (Seconds since 1970.)"""
	main_table = table(msname, ack=False)
	time_0 = quantity(main_table[0]['TIME'], get_scalar_col_unit(main_table, 'TIME'))
	obs_time = time_0 - mod_jul_day
	set_unit(obs_time, 's')
	return obs_time.get_value()

def get_time(ms, row):
	"""Return unix time of the observation. (Seconds since 1970.)"""
	time_0 = quantity(ms[row]['TIME'], get_scalar_col_unit(ms, 'TIME'))
	obs_time = time_0 - mod_jul_day
	set_unit(obs_time, 's')
	return obs_time.get_value()

tb = table(sys.argv[1], ack=False)
for i in range(len(tb)):
	row = tb[i]
	if row['ANTENNA1'] == int(sys.argv[2]):
		print datetime.datetime.utcfromtimestamp(get_time(tb, i))
