#!/usr/bin/env ParselTongue

import AIPS
from AIPSData import AIPSUVData
from pyrap.tables import table
from pyrap.quanta import quantity
import math
import time
import sys
import shutil
import datetime
import numpy

AIPS.userno = 2
mod_jul_day = quantity(40587.0, 'd')
mod_jul_day.convert(quantity(1.0, 's')) # Modified Julien day

uv = AIPSUVData('20030703', 'LINE', 1,1)
ms_name = 'AG650.MS'

sn = uv.table('SN', 1)
pols = sn.keywords['NO_POL']
ifs = sn.keywords['NO_IF']	# AIPS IF / Casa SPW

cal_table = sys.argv[1]
shutil.copytree('empty.gcal', cal_table)

ant_nums = []
ant = table(ms_name + '/ANTENNA', ack=False)
for row in ant:
	ant_nums.append(int(row['NAME'][-2:]))

obs_date = datetime.datetime(*[int(i) for i in uv.header.date_obs.split('-')])

# Make an CAL_DESC entry for each AIPS IF
#  default values:
cal_desc_defs = {'NUM_SPW': 1,
		 'NUM_CHAN': numpy.ones(shape=(1,), dtype='int32')
		 'NUM_RECEPTORS': pols,
		 'N_JONES': 2,
		 'CHAN_FREQ': numpy.zeros(shape=(1,1), dtype='float64'),
		 'MEAS_FREQ_REF': 0,
		 'CHAN_WIDTH': numpy.zeros(shape=(1,1), dtype='float64'),
		 'CHAN_RANGE': numpy.zeros(shape=(1,1,2), dtype='float64')
		 'POLARIZATION_TYPE': {'shape': [1, 1], 'array': ['']}
		 'JONES_TYPE': 'full'}

cal_desc = table(cal_table + '/CAL_DESC', ack=False, readonly=False)
cal_desc.addrows(ifs)
for i in range(ifs):
	cal_desc[i] = cal_desc_defs
	cal_desc[i] = {'SPECTRAL_WINDOW_ID': numpy.array((i,), dtype='int32')}
	cal_desc[i].update()
cal_desc.close()

# Default values for table entries
defs = {'SOLUTION_OK': numpy.ones(shape=(1,pols), dtype='bool'),
	'TOTAL_SOLUTION_OK': True,
        'TOTAL_FIT_WEIGHT': 1.0,
	'TOTAL_FIT': 1.0,
	'FIT': numpy.ones(shape=(1,1), dtype='float32'),
	'FIT_WEIGHT': numpy.ones(shape=(1,1), dtype='float32'),
        'FLAG': numpy.zeros(shape=(1,pols), dtype='bool'),
	'SNR': numpy.ones(shape=(1,pols), dtype='float32'),
	'GAIN': gain = numpy.ones(shape=(1, pols), dtype='complex64')}

gcal = table(cal_table, ack=False, readonly=False)
gcal.addrows(len(sn))
for i in range(len(sn)):
	gcal[i] = defs
	sol_time = obs_date + datetime.timedelta(float(sn[i].time))
	time_unix = time.mktime(sol_time.timetuple())
	time_casa = time_unix + mod_jul_day.get_value()
	time_interval = quantity(sn[i].time_interval, 'd')
	time_interval.convert(quantity(1.0, 's'))
	time_interval = time_interval.get_value()
	try:
		antenna1 = ant_nums.index(sn[i].antenna_no)
	except ValueError:
		print sn[i].antenna_no, 'not in ms'
	gain = gcal[i]['GAIN']
	for p in range(pols):
		gain[0][p] = sn[i]['real%d' % (p+1)] + 1j * sn[i]['imag%d' % (p+1)]
	snr = gcal[i]['SNR']
	for p in range(pols):
		snr[0][p] = sn[i]['weight_%d' % (p+1)]
	gcal[i] = {'TIME': time_casa, 'INTERVAL': time_interval,
		   'GAIN': gain, 'SNR': snr, 'ANTENNA1': antenna1}
	gcal[i].update()
gcal.close()
