#!/usr/bin/env ParselTongue
#
# Tool to convert AIPS SN tables into Measurement Set Calibration tables
# Stephen Bourke, JIVE

import AIPS
from AIPSData import AIPSUVData, AIPSCat
from pyrap.tables import table
from pyrap.quanta import quantity
import math
import sys
import shutil
import datetime
import calendar
import numpy
import os.path

mod_jul_day = quantity(40587.0, 'd')
mod_jul_day.convert(quantity(1.0, 's')) # Modified Julien day

if len(sys.argv) != 7 and len(sys.argv) != 8:
	print >> sys.stderr, 'Usage: %s <userno> <disk> <cno> <snver> <ms> <outcal> [antfile]' % sys.argv[0]
	sys.exit()
AIPS.userno, disk, cno, snver = [int(i) for i in sys.argv[1:5]]
ms_name, cal_table = sys.argv[5:7]
try:
	antfile = sys.argv[7]
except IndexError:
	antfile = None

ds = [i for i in AIPSCat()[disk] if i['cno'] == cno][0]
uv = AIPSUVData(ds['name'], ds['klass'], disk, ds['seq'])
obs_date = datetime.datetime(*[int(i) for i in uv.header.date_obs.split('-')])

print uv, 'SN%d' % snver, '->', ms_name, cal_table

sn = uv.table('SN', snver)
pols = sn.keywords['NO_POL']
ifs = sn.keywords['NO_IF']	# AIPS IF / Casa SPW

# User specified mapping from AIPS ants to MS ant ids
ant_aips2ms = {}
if antfile:
	inf = open(antfile)
	for line in inf:
		aips_ant_no, ms_ant_id = [int(x) for x in line.split()]
		ant_aips2ms[aips_ant_no] = ms_ant_id
	inf.close()

shutil.copytree('empty.gcal', cal_table)
# Make an CAL_DESC entry for each AIPS IF
cal_desc_defs = {'NUM_SPW': 1,
		 'NUM_CHAN': numpy.ones(shape=(1,), dtype='int32'),
		 'NUM_RECEPTORS': pols,
		 'N_JONES': 2,
		 'CHAN_FREQ': numpy.zeros(shape=(1,1), dtype='float64'),
		 'MEAS_FREQ_REF': 0,
		 'CHAN_WIDTH': numpy.zeros(shape=(1,1), dtype='float64'),
		 'CHAN_RANGE': numpy.zeros(shape=(1,1,2), dtype='int32'),
		 'POLARIZATION_TYPE': {'shape': [1, 1], 'array': ['']},
		 'JONES_TYPE': 'full',
		 'MS_NAME': os.path.basename(ms_name)}

cal_desc = table(cal_table + '/CAL_DESC', ack=False, readonly=False)
cal_desc.addrows(ifs)
for i in range(ifs):
	cal_desc[i] = cal_desc_defs
	cal_desc[i] = {'SPECTRAL_WINDOW_ID': numpy.array((i,), dtype='int32')}
	cal_desc[i].update()
cal_desc.close()

# Make the CAL_MAIN table
defs = {'SOLUTION_OK': numpy.ones(shape=(1,pols), dtype='bool'),
	'TOTAL_SOLUTION_OK': True,
        'TOTAL_FIT_WEIGHT': 1.0,
	'TOTAL_FIT': 1.0,
	'FIT': numpy.ones(shape=(1,1), dtype='float32'),
	'FIT_WEIGHT': numpy.ones(shape=(1,1), dtype='float32'),
        'FLAG': numpy.zeros(shape=(1,pols), dtype='bool')}

gcal = table(cal_table, ack=False, readonly=False)
gcal.addrows(len(sn) * ifs)
progress_num = 0
progress_dot = 2.51
for i in range(len(sn)):
	progress_done = float(i) / len(sn) * 100
	if progress_done > progress_num:
		sys.stdout.write('%d%%' % progress_num)
		sys.stdout.flush()
		progress_dot = progress_num + 2.51
		progress_num += 10
	if progress_done > progress_dot:
		sys.stdout.write('.')
		sys.stdout.flush()
		progress_dot += 2.51
	sol_time = obs_date + datetime.timedelta(float(sn[i]['time']))
	time_unix = calendar.timegm(sol_time.timetuple())
	time_casa = time_unix + mod_jul_day.get_value()
	time_interval = quantity(sn[i]['time_interval'], 'd')
	time_interval.convert(quantity(1.0, 's'))
	time_interval = time_interval.get_value()
	field_id = sn[i]['source_id'] - 1
	if antfile:
		antenna1 = ant_aips2ms[sn[i]['antenna_no']]
	else:
		antenna1 = sn[i]['antenna_no'] - 1
	for iif in range(ifs):
		row = iif * len(sn) + i
		gcal[row] = defs
		gain = numpy.ones(shape=(1, pols), dtype='complex64')
		snr = numpy.ones(shape=(1,pols), dtype='float32')
		for p in range(pols):
			if ifs == 1:
				gain[0][p] = sn[i]['real%d' % (p+1)] + 1j * sn[i]['imag%d' % (p+1)]
				snr[0][p] = sn[i]['weight_%d' % (p+1)]
			else:
				gain[0][p] = sn[i]['real%d' % (p+1)][iif] + 1j * sn[i]['imag%d' % (p+1)][iif]
				snr[0][p] = sn[i]['weight_%d' % (p+1)][iif]
		gcal[row] = {'TIME': time_casa, 'INTERVAL': time_interval,
			   'GAIN': gain, 'SNR': snr, 'ANTENNA1': antenna1,
			   'CAL_DESC_ID': iif, 'FIELD_ID': field_id}
		gcal[row].update()
print '100%'
gcal.close()
