#!/usr/bin/env ParselTongue
#
# Tool to convert AIPS SN tables into Measurement Set Calibration tables
# Stephen Bourke, JIVE
# Nov, 2010

import AIPS
from AIPSData import AIPSUVData, AIPSCat
from pyrap.tables import table
from pyrap.quanta import quantity
import math
import time
import sys
import shutil
import datetime
import calendar
import numpy
import os.path

mod_jul_day = quantity(40587.0, 'd')
mod_jul_day.convert(quantity(1.0, 's')) # Modified Julien day

if len(sys.argv) != 7:
	print >> sys.stderr, 'Usage: %s <userno> <disk> <cno> <snver> <ms> <outcal>' % sys.argv[0]
	sys.exit()
AIPS.userno, disk, cno, snver = [int(i) for i in sys.argv[1:5]]
ms_name, cal_table = sys.argv[5:7]

ds = [i for i in AIPSCat()[disk] if i['cno'] == cno][0]
uv = AIPSUVData(ds['name'], ds['klass'], disk, ds['seq'])
obs_date = datetime.datetime(*[int(i) for i in uv.header.date_obs.split('-')])

print uv, 'SN%d' % snver, '->', ms_name, cal_table

sn = uv.table('SN', snver)
pols = sn.keywords['NO_POL']
ifs = sn.keywords['NO_IF']	# AIPS IF / Casa SPW

for i in range(len(sn)):
	if sn[i].antenna_no != 1:
		continue
	sol_time = obs_date + datetime.timedelta(sn[i]['time'])
	time_unix = calendar.timegm(sol_time.timetuple())
	print datetime.datetime.utcfromtimestamp(time_unix)
