# Create empty Cal tables. The following string is a base64 encoded
# gzip'd tarfile containing empty tables for G, B, K, KMBD Jones
# calibrations. Tables created from scratch in python were somehow
# different than those created in Casa and didn't work so I resorted
# to this method.
#
# Stephen Bourke, jive
# Dec, 2010

import tarfile
import StringIO
import base64

cal_tgz = """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=
"""

def extract(cal_type, outname):
	if cal_type not in ['gcal', 'bcal', 'mbdcal', 'sbdcal']:
		raise ValueError, 'Unknown Cal type: %s' % cal_type
	inf = StringIO.StringIO(base64.decodestring(cal_tgz))
	tf = tarfile.open(fileobj=inf, mode='r:gz')
	for tinfo in tf.getmembers():
		if not tinfo.name.startswith('empty.%s' % cal_type):
			continue
		tinfo.name = tinfo.name.replace('empty', outname, 1)
		tf.extract(tinfo)
	inf.close()

# Alias for extract
create = extract

if __name__ == '__main__':
	import sys
	extract(sys.argv[1], sys.argv[2])
