#!/usr/bin/env python
#
# Program to convert correlations (LL,XX, etc) to stokes I,Q,U,V.
# Stephen Bourke, jive
# Augest, 2011

import numpy
import progress
from taskinit import casalog
from casa_utils import table, ms_subtable

def lin2stokes(inarr, outarr):
	outarr[0,:,:] = 0.5 * (inarr[0,:,:] + inarr[3,:,:])
	outarr[1,:,:] = 0.5 * (inarr[0,:,:] - inarr[3,:,:])
	outarr[2,:,:] = 0.5 * (inarr[1,:,:] + inarr[2,:,:])
	outarr[3,:,:] = (inarr[1,:,:] - inarr[2,:,:]) / 2j

def circ2stokes(inarr, outarr):
	outarr[0,:,:] = 0.5 * (inarr[0,:,:] + inarr[3,:,:])
	outarr[1,:,:] = 0.5 * (inarr[1,:,:] + inarr[2,:,:])
	outarr[2,:,:] = (inarr[1,:,:] - inarr[2,:,:]) / 2j
	outarr[3,:,:] = 0.5 * (inarr[0,:,:] - inarr[3,:,:])

def half2stokes(inarr, outarr):
	outarr[0,:,:] = 0.5 * (inarr[0,:,:] + inarr[1,:,:])
	outarr[1,:,:] = 0.5 * (inarr[0,:,:] - inarr[1,:,:])

def stokesdata(msname, nrows=2**10):
	"""Convert DATA column to I,Q,U,V.

	 Input data must be either ['XX', 'XY', 'YX', 'YY']
	or ['RR', 'RL', 'LR', 'LL']."""

	casalog.origin('stokesdata')
	ms = table(msname, readonly=False)
	pol = ms_subtable(ms, 'POLARIZATION', readonly=False)
	if pol.nrows() != 1:
		casalog.post('Multiple polarization setups present. Quitting')
		return
	pols = pol.getcell('CORR_TYPE', 0)
	#FIXME
	if list(pols) == [5, 6, 7, 8]:
		stokes_convf = circ2stokes
	elif list(pols) == [9, 10, 11, 12]:
		stokes_convf = lin2stokes
	elif list(pols) == [5, 8] or list(pols) == [9, 12]:
		stokes_convf = half2stokes
	else:
		casalog.post('Unknown CORR_TYPE ' + str(pols) + '. Quitting.')
		return

	startrow = 0
	vis_data = ms.getcol('DATA', startrow, nrows)
	vis_new = numpy.empty(shape=vis_data.shape, dtype=vis_data.dtype)
	casalog.post('Converting stokes')
	shift_progress = progress.progress(ms.nrows())
	for i in range(ms.nrows()):
		if i >= startrow + nrows:
			# Write back data and get next set of rows
			ms.putcol('DATA', vis_new, startrow, nrows)
			startrow += nrows
			vis_data = ms.getcol('DATA', startrow, nrows)
			if vis_data.shape != vis_new.shape:
				vis_new = numpy.empty(shape=vis_data.shape, dtype=vis_data.dtype)
		stokes_convf(vis_data, vis_new)
		shift_progress.update(i)
	ms.putcol('DATA', vis_new, startrow, nrows)
	shift_progress.done()
	ms.close()
	
	# Update CORR_TYPE in the POLARIZATION table.
	casalog.post('Updating data in POLARIZATION table.')
	# FIXME
	if list(pols) == [5, 8]:
		pols[:] = [1, 4]
	elif list(pols) == [9, 12]:
		pols[:] = [1, 2]
	else:
		pols[:] = [1, 2, 3, 4]
	pol.putcell('CORR_TYPE', 0, pols)
	pol.close()
