from taskinit import casalog
import numpy
import sys
from casa_utils import table, get_field_id

def tbavg(msname, field='', datacolumn='data', outfile=None, chanavg=True, nrows=2**10):
	if field != '':
		field_sel = 'FIELD_ID==%d' % get_field_id(msname, field)
	else:
		field_sel = ''
	if outfile:
		outf = open(outfile, 'w')
	else:
		outf = sys.stdout
	datacolumn = {'data': 'DATA', 'corrected': 'CORRECTED_DATA'}[datacolumn]

	ms = table(msname)
	startrow = 0
	subt = ms.query(field_sel, columns='TIME, FLAG, FLAG_ROW, DATA_DESC_ID, %s' % datacolumn, sortlist='TIME')
	time = subt.getcol('TIME', startrow, nrows)
	flag = subt.getcol('FLAG', startrow, nrows)
	flag_row = subt.getcol('FLAG_ROW', startrow, nrows)
	ddsc = subt.getcol('DATA_DESC_ID', startrow, nrows)
	data = subt.getcol(datacolumn, startrow, nrows)
	pols, chans, num_vis = data.shape

	spws = table(msname + '/SPECTRAL_WINDOW').nrows()
	data_desc = table(msname + '/DATA_DESCRIPTION')
	desc2spw = data_desc.getcol('SPECTRAL_WINDOW_ID')
	data_desc.close()

	if chanavg:
		vis_shape = (pols,)
	else:
		vis_shape = (spws, pols, chans)

	data_sum = numpy.zeros(shape=vis_shape, dtype='complex')
	navg = numpy.zeros(shape=vis_shape, dtype='int')

	t_prev = time[0]
	for i in range(subt.nrows()):
		if i >= startrow + nrows:
			# FIXME: do more checks here for array limits
			startrow += nrows
			time = subt.getcol('TIME', startrow, nrows)
			flag = subt.getcol('FLAG', startrow, nrows)
			flag_row = subt.getcol('FLAG_ROW', startrow, nrows)
			ddsc = subt.getcol('DATA_DESC_ID', startrow, nrows)
			data = subt.getcol(datacolumn, startrow, nrows)
		indx = i % nrows
		if time[indx] > t_prev:
			if navg.any():
				data_sum /= navg
				print >> outf, t_prev,
				for x in numpy.nan_to_num(data_sum.real.ravel()):
					print >> outf, x,
				print >> outf
			data_sum[:] = 0
			navg[:] = 0
		t_prev = time[indx]
		data_ok = numpy.logical_not(flag[:,:,indx]) * numpy.logical_not(flag_row[indx])
		spw = desc2spw[ddsc[indx]]
		if chanavg:
			data_sum += (data[:,:,indx] * data_ok).sum(1)
			navg += data_ok.sum(1)
		else:
			data_sum += (data[:,:,indx] * data_ok)
			navg += data_ok
	outf.flush()
	if outfile:
		outf.close()
	subt.close()
	ms.close()
