# General astro functions.
# Stephen Bourke, NUI Galway, JIVE.

import math

def shift_asec(ra, dec, ra0, dec0):
	"""Calculate the shift between two positions.

	Given a RA's and DEC's in hours, degrees respectively
	calculate the x,y shift in arc-seconds. Useful for UVFIX."""
	
	# Convert RA to degrees
	ra = 15 * ra
	ra0 = 15 * ra0
	
	shift_x = 3600 * math.cos(math.radians(dec0)) * (ra - ra0)
	shift_y = 3600 * (dec - dec0)
	
	return shift_x, shift_y

def distance_asec(ra, dec, ra0, dec0):
	"""Calculate the distance in asec bewteen the two positions."""
	
	ra_shift, dec_shift = shift_asec(ra, dec, ra0, dec0)
	return math.hypot(ra_shift, dec_shift)

def ra_add_asec(ra, dec, asec):
	"""Given a RA and DEC add the value 'asec' to the RA."""
	ra = 15 * ra
	
	new_ra = ra + asec / (3600*math.cos(math.radians(dec)))
	new_ra = new_ra / 15
	
	return new_ra
