# Gereral functions.
# Stephen Bourke, NUI Galway, JIVE.

import re, random, sys, string

def rand_string(length=8):
    """Returns a string of random alpha numeric characters."""
    chars = string.ascii_letters + string.digits
    chars_len = len(chars)
    
    rand_str = ''
    for i in range(length):
        rand_str = rand_str + chars[random.randint(0,chars_len-1)]
    return rand_str


def mode(arr):
    """Returns the Mode of a list of numbers"""
    freq = {}
    for num in arr:
        if num in freq:
            freq[num] += 1
        else:
            freq[num] = 1
    max_occurances = 0
    for num in freq:
        if freq[num] > max_occurances:
            max_occurances = freq[num]
            mode = num
    return mode


def median(arr):
    """Returns the median of the input array."""
    assert len(arr) > 1
    arr.sort()
    return arr[len(arr)/2]


def str2nums(str, type=float):
        """Returns a list of numbers found in string str. These are then converted to
    a specific type if specified (default is float.)
    Eg. str2nums('abc 2.3 asdf 2e-4 xyz', type=int)"""
        return [type(i) for i in re.findall('([+-]?\d+(?:\.\d+)?(?:[eE][+-]?\d+)?)', str)]


def next_binary(num):
    """Return the next power of two. Eg. 138->256, 512->512, 520->1024"""
    binary = 1
    while num > binary:
        binary *= 2
    return binary


def dict2str(dic):
	"""Returns a string representation of the given dictionary."""
	return ' '.join(['%s=%s' % pair for pair in dic.items()])


def load_settings(cfg_name):
    """Return a dictionary of value,settings pairs."""
    pair_re = re.compile('(.*)=(.*)')
    comment_re = re.compile('^\s*#.*')
    empty_re = re.compile('^\s*$')
    settings = {}
    cfg_file = open(cfg_name)
    for line in cfg_file:
        if comment_re.match(line) or empty_re.match(line):
            continue
        setting_match = pair_re.match(line)
        if setting_match:
            pair = setting_match.groups()
            settings[pair[0].strip()] = pair[1].strip()
        else:
            print >> sys.stderr, 'Could not match line:', line.rstrip()
            raise IOError
    cfg_file.close()
    return settings
