import AIPS
from AIPSData import AIPSUVData, AIPSImage
import re

def out_files(task):
    """Tries to deduce the files created by last invocation of task object.
    
    It does this by looking for lines in the tasks output of the form:
    TSKNM1: Create NAME        .CLASS .   1 (MA)  on disk  1  cno    1
    It will not work if the task doesn't produce such messages."""
    
    # Regex to extract name, class, sequence, type, and catalog number from a line as above.
    pattern = re.compile('.*Create (.{12})\.(.{6})\.\s*(\d+)\s*\((..)\)\s*on disk\s*(\d+)\s*cno\s*(\d+)')
    
    outfiles = []
    for line in task.messages():
        match = pattern.match(line) 
        if match:
            name, klass, seq, typ, localdisk, cno = match.groups()
            name, klass = [i.rstrip(' ') for i in (name, klass)]
            seq, localdisk, cno = [int(i) for i in (seq, localdisk, cno)]

            # Check for ambiguity (can occur with remote disks)
            matches = 0
            for i in range(1, len(AIPS.disks)):
                if AIPS.disks[i].disk != localdisk:
                    continue
                if typ == 'UV':
                    dataset = AIPSUVData(name, klass, i, seq)
                elif typ == 'MA':
                    dataset = AIPSImage(name, klass, i, seq)
                else:
                    continue
                if dataset.exists():
                    outfiles.append(dataset)
                    matches += 1
            if matches > 1:
                raise RuntimeError, 'Could not determine output (ambiguous datasets)'
    return outfiles
