#!/usr/bin/env python

import re, socket, os, shutil, sys
from AIPSUtil import ehex

def setup_host(hostname=None):
    if not hostname:
    	hostname = socket.gethostname()
    hostname = hostname.upper()
    hosts_list_re = re.compile('^[+-=]  (\S*) *(\S*) *(\S*) *(\S*) *.*$')
    
    # Check if machine is in HOSTS.LIST
    hostf = open(os.environ['AIPS_ROOT'] + '/HOSTS.LIST', 'r')
    host_found = False
    for line in hostf:
        match = hosts_list_re.match(line)
        if match:
            host, arch, site, srv = match.groups()
            if host == hostname:
                host_found = True
                break
    hostf.close()
    
    # Add entry to HOSTS.LIST if necessary.
    if not host_found:
        print 'Adding host', hostname, 'to HOSTS.LIST'
        hostf = open(os.environ['AIPS_ROOT'] + '/HOSTS.LIST', 'a')
        print >> hostf, '+  %s    %s    %s    NONE  Cluster node' % \
            (hostname, os.environ['ARCH'], os.environ['SITE'])
        hostf.close()
    
    # Create DA00 directory if necessary.
    da00 = os.environ['NET0'] + '/' + hostname
    if not os.path.exists(da00):
        print 'Copying TEMPLATE directory to', da00
        template_path = os.environ['AIPS_ROOT'] + '/31DEC07/' + \
            os.environ['ARCH'] + '/TEMPLATE'
        shutil.copytree(template_path, da00)


def make_disk(path):
    """Make the directory and put the 'SPACE' file in it."""
    space_file = path + '/SPACE'
    if not os.path.exists(space_file):
        if not os.path.isdir(path):
            os.mkdir(path)
        open(space_file, 'w').close()


def disk_list_add(*args, **kwargs):
    """Add DAxx entries for the directories supplied and update NVOL."""
    try:
        nvol = int(os.environ['NVOL'])
    except KeyError:
        nvol = 0
    try:
        if kwargs['clear_list']:
              nvol = 0
    except KeyError:
        pass
    for i in range(len(args)):
        os.environ['DA%s' % ehex(nvol+1+i, 2, 0)] = args[i]
    os.environ['NVOL'] = str(nvol + len(args))


if __name__ == '__main__':
    if len(sys.argv) > 1:
        for host in sys.argv[1:]:
            setup_host(host)
    else:
        setup_host()
