#!/usr/bin/env python

# Create a text file of antenna parameters from Lofar locations.
# Stephen Bourke, JIVE.
# Sept, 2009.
#
# Version: 20090930

import re
import sys

station = 'LOFAR'
mount = 'ALT-AZ'

lofar_re = re.compile('(?:CS|RS|DE)\d{3}[LH]BA[01]?')

def is_lofar_name(name):
	if lofar_re.match(name):
		return True
	else:
		return False

# Sizes of lofar stations
# http://www.astron.nl/radio-observatory/astronomers/users/technical-information/lofar-stations/lofar-stations-description-
def lofar_size(name):
	if (name.startswith('CS') or name.startswith('RS')) and name.endswith('LBA'):
		# Core and Remote LBA
		return 87
	elif name.endswith('LBA'):
		# International LBA
		return 70
	elif name.endswith('HBA0') or name.endswith('HBA1'):
		# Core HBA
		return 35
	elif name.startswith('RS') and name.endswith('HBA'):
		# Remote HBA
		return 50.2
	elif name.endswith('HBA'):
		# International HBA
		return 62
	else:
		raise ValueError, "%s doesn't appear to be a lofar ant" % name

if len(sys.argv) != 2 and len(sys.argv) != 3:
	print >> sys.stderr, 'Usage: %s <lofar_locs> [outfile]' % sys.argv[0]
	sys.exit()
location_file = sys.argv[1]
try:
	outf = open(sys.argv[2], 'w')
except IndexError:
	outf = sys.stdout

inf = open(location_file)
for line in inf:
	fields = line.split('|')[1:-1]
	if len(fields) != 4:
		continue
	name, x, y, z = [f.strip() for f in fields]
	if not (is_lofar_name(name) and x and y and z):
		continue
	print >> outf, name, station, x, y, z, mount, lofar_size(name)
