#!/usr/bin/env python

import sys
import math

loc_file512 = 'mwa_512_crossdipole_gp_20080714.txt'
name512 = 'MWA512'
loc_file32 = 'mwa_32.txt'
name32 = 'MWA32T'

arr_lat = math.radians(-26.4311111111111)
arr_lon = math.radians(117.357)
earth_r = 6378100.0

def cart2sph(coord):
	x,y,z = coord
	r = math.sqrt(x**2 + y**2 + z**2)
	lat = -1 * (math.atan(math.sqrt(x**2 + y**2)/z) - (math.pi / 2))
	lon = math.atan2(y,x)
	if lat > math.pi / 2:
		lat -= math.pi
	return r, lon, lat

def sph2cart(coord):
	r, lon, lat = coord
	lat = -1 * lat + math.pi/2
	x = r * math.sin(lat) * math.cos(lon)
	y = r * math.sin(lat) * math.sin(lon)
	z = r * math.cos(lat)
	return x, y, z

if len(sys.argv) != 2:
	print >> sys.stderr, 'Usage: %s <32T|512>' % sys.argv[0]
	sys.exit()
if sys.argv[1] == '32T':
	loc_file = loc_file32
	name = name32
elif sys.argv[1] == '512':
	loc_file = loc_file512
	name = name512
else:
	print >> sys.stderr, 'Usage: %s <32T|512>' % sys.argv[0]
	sys.exit()
	
inf = open(loc_file)
i = 1
for line in inf:
	if line.strip().startswith('#') or line.strip() == '':
		continue
	e, n, txt = line.split()
	e, n = float(e), float(n)
	x, y, z = earth_r, e, n
	r, lon, lat = cart2sph((x, y, z))
	lon += arr_lon
	lat += arr_lat
	x, y, z = sph2cart((r, lon, lat))
	print '%s_%03d MWA' % (name, i), x, y, z, 'ALT-AZ 5'
	i += 1
