#!/usr/bin/env python

import sys
import math
import numpy
from positions import get_positions

conffile = 'AntennaArraysRS208.conf'
station = 'RS208'

earth_radius = 6378100.0

def cart2sph(coord):
	x,y,z = coord
	r = math.sqrt(x**2 + y**2 + z**2)
	lat = -1 * (math.atan(math.sqrt(x**2 + y**2)/z) - (math.pi / 2))
	lon = math.atan2(y,x)
	if lat > math.pi / 2:
		lat -= math.pi
	return r, lon, lat

def sph2cart(coord):
	r, lon, lat = coord
	lat = -1 * lat + math.pi/2
	x = r * math.sin(lat) * math.cos(lon)
	y = r * math.sin(lat) * math.sin(lon)
	z = r * math.cos(lat)
	return x, y, z

if len(sys.argv) != 2 and len(sys.argv) != 3:
	print >> sys.stderr, 'Usage: %s <array> [scaling]' % sys.argv[0]
	sys.exit()

arr_name = sys.argv[1]
try:
	scaling = float(sys.argv[2])
except IndexError:
	scaling = 1

positions = get_positions(conffile, arr_name)
xyz_locs = positions['ant_pos']
arr_lon = math.radians(positions['array_pos'][0])
arr_lat = math.radians(positions['array_pos'][1])
arr_alt = positions['array_pos'][2]

# Check if positions are duplicated (X and Y dipoles)
if numpy.all(xyz_locs[:,0,:] == xyz_locs[:,1,:]):
	xyz_locs = xyz_locs[:,0,:]
else:
	# Single Pol
	xyz_locs = numpy.concatenate((xyz_locs[:,0,:], xyz_locs[:,1,:]))

i = 1
for xyz in xyz_locs:
	x0, y0, z0 = scaling * xyz
	z0 += earth_radius + arr_alt
	x, y, z = z0, x0, y0
	r, lon, lat = cart2sph((x, y, z))
	lon += arr_lon
	lat += arr_lat
	x, y, z = sph2cart((r, lon, lat))
	print '%s:%02d %s:%s' % (arr_name, i, station, arr_name), x, y, z, 'ALT-AZ 1'
	i += 1
