#!/usr/bin/env python

# Create a text file of antenna parameters from a SCHED location file.
# Stephen Bourke, JIVE.
# Sept, 2009.
#
# Version: 20090930

import re
import sys

default_dish_size = 25
# Antenna size overrides
ANT_SIZE = {'EB': 100, 'JB': 76, 'MC': 32, 'NT':32, 'ON': 20, 'TR': 32,
            'MH': 14, 'YB': 40, 'AR': 305, 'WZ': 20, 'RO': 70, 'DS65': 34,
            'KB': 34, 'MA': 20, 'NY': 20, 'GT': 100, 'JB2': 32, 'CM': 32}
            # WB, Y ?

if len(sys.argv) != 2 and len(sys.argv) != 3:
	print >> sys.stderr, 'Usage: %s <sched_locs> [outfile]' % sys.argv[0]
	sys.exit()
location_file = sys.argv[1]
try:
	outf = open(sys.argv[2], 'w')
except IndexError:
	outf = sys.stdout

# REs for parsing SCHED locations file
comment_line = re.compile('^!')
name_line = re.compile("\s*DBCODE='?\s*(\w+)'?\s*DBNAME='?([\w-]+)'?\s*AXISTYPE='(\w+)'\s*AXISOFF=\s*(-?\d+\.\d+)\s*")
xyz_line = re.compile('\s*X=\s*(-?\d+\.\d+)\s*Y=\s*(-?\d+\.\d+)\s*Z=\s*(-?\d+\.\d+)\s*')
end_block = re.compile('^/')

# Get antenna parms from file
ant_list = []
have_name = False
have_xyz = False

inf = open(location_file)
for line in inf:
	if comment_line.match(line):
		continue
	name_match = name_line.match(line)
	if name_match:
		have_name = True
		code, name, mount, offset = name_match.groups()
		# TODO: use the offset and DT values too?
		if mount == 'alta' or mount == 'altz' or mount == 'altaz':
			mount = 'ALT-AZ'
		elif mount == 'equa':
			mount = 'EQUATORIAL'
		elif mount == 'spac':
			mount = 'SPACE-HALCA'
		elif mount == 'xyEW' or mount == 'xyNS':
			mount = 'X-Y'
		else:
			print >> sys.stderr, 'Unknown mount %s on %s using alt-az' % (mount, code)
			mount = 'ALT-AZ'
	xyz_match = xyz_line.match(line)
	if xyz_match:
		have_xyz = True
		x, y, z = [float(i) for i in xyz_match.groups()]
	if end_block.match(line):
		assert have_name and have_xyz
		if code in ant_list:
			print >> sys.stderr, 'Warning: Duplicate entries for "%s" found in locations file. Using first found.' % code
		if code in ANT_SIZE:
			dish_size = float(ANT_SIZE[code])
		elif name == 'LOFAR':
			dish_size = lofar_size(code)
		else:
			dish_size = default_dish_size
		print >> outf, code, name, x, y, z, mount, dish_size
		have_name = False
		have_xyz = False
