import pyrap_tables
from pyrap_tables import tablecreatescalarcoldesc as cldsc
from pyrap_tables import tablecreatearraycoldesc as clarrdsc
import re
import sys

ANTENNAS = ['CM', 'EB', 'JB2', 'LA']
location_file = 'locations.dat'

class ord_dict(dict):
    def __init__(self):
        dict.__init__(self)
        self._order = []
    def __setitem__(self, key, value):
        self._order.append(key)
        dict.__setitem__(self, key, value)
    def keys(self):
        return self._order
    def __iter__(self):
        self._iter_n = 0
        return self
    def next(self):
        if self._iter_n == len(self._order):
            raise StopIteration
        self._iter_n += 1
        return self._order[self._iter_n - 1]

def tablecreatedesc(descs=[]):
    rec = ord_dict()
    for desc in descs:
        colname = desc['name']
        if rec.has_key(colname):
            raise ValueError('Column name ' + name + ' multiply used in table description')
        rec[colname] = desc['desc']
    return rec;

comment_line = re.compile('^!')
name_line = re.compile("\s*DBCODE=\s*(\w+)\s*DBNAME=([\w-]+)\s*AXISTYPE='(\w+)'\s*AXISOFF=\s*(-?\d+\.\d+)\s*")
xyz_line = re.compile('\s*X=\s*(-?\d+\.\d+)\s*Y=\s*(-?\d+\.\d+)\s*Z=\s*(-?\d+\.\d+)\s*')
end_block = re.compile('^/')

ant_list = []
have_name = False
have_xyz = False
inf = open(location_file)
for line in inf:
	if comment_line.match(line):
		continue
	name_match = name_line.match(line)
	if name_match:
		have_name = True
		code, name, mount, offset = name_match.groups()
		if mount == 'alta' or mount == 'altz':
			mount = 'ALT-AZ'
		elif mount == 'equa':
			mount = 'EQUATORIAL'
		elif mount == 'spac':
			mount = 'SPACE-HALCA'
		elif mount == 'xyEW' or mount == 'xyNS':
			mount = 'X-Y'
		else:
			print >> sys.stderr, 'Unknown mount', mount
	xyz_match = xyz_line.match(line)
	if xyz_match:
		have_xyz = True
		x, y, z = [float(i) for i in xyz_match.groups()]
	if end_block.match(line):
		assert have_name and have_xyz
		have_name = False
		have_xyz = False
		if code in ANTENNAS:
			ant_list.append({'POSITION': [x,y,z], 'MOUNT': mount,
				'STATION': name, 'NAME': code})
inf.close()

offset_desc = clarrdsc('OFFSET', value=float(), ndim=1, shape=[3])
position_desc = clarrdsc('POSITION', value=float(), ndim=1, shape=[3])
type_desc = cldsc('TYPE', value=str())
dish_desc = cldsc('DISH_DIAMETER', value=float())
flag_desc = cldsc('FLAG_ROW', value=bool())
mount_desc = cldsc('MOUNT', value=str())
name_desc = cldsc('NAME', value=str())
station_desc = cldsc('STATION', value=str())

desc = tablecreatedesc([offset_desc, position_desc, type_desc,
        dish_desc, flag_desc, mount_desc, name_desc, station_desc])

t = pyrap_tables.table('SB_ANT', desc, nrow=len(ant_list), readonly=False)
#t = pyrap_tables.table('SB_ANT', desc, readonly=False)
t.putcolkeywords('OFFSET', {'QuantumUnits': ['m', 'm', 'm'],
    'MEASINFO': {'Ref': 'ITRF', 'type': 'position'}})
t.putcolkeywords('POSITION', {'QuantumUnits': ['m', 'm', 'm'],
    'MEASINFO': {'Ref': 'ITRF', 'type': 'position'}})
t.putcolkeywords('DISH_DIAMETER', {'QuantumUnits': ['m']})
for i in range(len(ant_list)):
	t[i] = ant_list[i]
t[:] = {'DISH_DIAMETER': 25.0, 'OFFSET': [0.0,0.0,0.0], 'TYPE': 'GROUND-BASED', 'MOUNT': 'ALT-AZ'}
