#!/usr/bin/env python
#
# Program to geometrically shift a field in a Measurement Set
# Stephen Bourke, jive
# Dec, 2010

from pyrap.tables import table
import math
import numpy
import sys
import cmath
import progress

if len(sys.argv) != 5:
	print >> sys.stderr, 'Usage: %s <ms> <field> <ra_shift_asec> <dec_shift_asec>' % sys.argv[0]
	sys.exit()

msname = sys.argv[1]
field_id = int(sys.argv[2])
rashift, decshift = [math.radians(float(i) / 3600) for i in sys.argv[3:]]

C = 299792458.0
data_col = 'CORRECTED_DATA'

# Wavelengths
spw = table(msname + '/SPECTRAL_WINDOW', ack=False)
wl = C / spw.getcol('CHAN_FREQ')
spw.close()

# DataDescID to SPW mapping
desc = table(msname + '/DATA_DESCRIPTION', ack=False)
desc2spw = desc.getcol('SPECTRAL_WINDOW_ID')
desc.close()

# Rotate UVWs and update phase
ms =  table(msname, readonly=False, ack=False)
shift_progress = progress.progress(len(ms))
for i in range(len(ms)):
	if ms[i]['FIELD_ID'] != field_id:
		continue
	# Shift the UVW
	uvw = ms[i]['UVW']
	u0,v0,w0 = uvw
	baseline_uw = complex(u0, w0)
	rotation_v = baseline_uw * cmath.rect(1, rashift)
	u1, w_int = rotation_v.real, rotation_v.imag
	baseline_vw = complex(v0, w_int)
	rotation_u = baseline_vw * cmath.rect(1, decshift)
	v1, w1 = rotation_u.real, rotation_u.imag
	uvw[:] = [u1, v1, w1]
	# Shift the visibilities based on the delay (w) difference
	spw = desc2spw[ms[i]['DATA_DESC_ID']]
	delay_angle = (w1 - w0) / wl[spw] * -2 * math.pi
	complex_delay = numpy.exp(1j * delay_angle)
	vis = ms[i][data_col]
	for corr in range(vis.shape[1]):
		vis[:,corr] *= complex_delay
	ms[i] = {data_col: vis, 'UVW': uvw}
	shift_progress.update(i)
shift_progress.done()

# Update metadata
field = table(msname + '/FIELD', readonly=False, ack=False)
direction = field[field_id]['PHASE_DIR']
ra0, dec0 = direction[0]
dec = dec0 + decshift
ra = ra0 + rashift / math.cos(dec0)
direction[0,:] = [ra, dec]
field[field_id] = {'PHASE_DIR': direction}
field.close()
