#!/usr/bin/env ParselTongue

# Get the last inputs to a task (like TGET) and display
# the equivalent ParselTongue code.
#
# Stephen Bourke, JIVE.
# July, 2009.

from Proxy.AIPSTask import _AIPSTaskParams
from AIPSUtil import ehex
import struct
import sys
import os

filename = os.environ['DA01'] + '/TGD0B4000.%s;'

header = 'iiiii'
dir_entry = '8siii'
vname = [None, 'OLD', 'NEW', 'TST', 'OLDPSAP',
         'NEWPSAP', 'TSTPSAP', 'LOCAL', 'PRIVATE']

def int2date(date):
        """Convert the AIPS catalog date value to a string."""
        # Date is of the form 0xYYMMDD
        months = ['ERR', 'JAN', 'FEB', 'MAR', 'APR', 'MAY', 'JUN',
                         'JUL', 'AUG', 'SEP', 'OCT', 'NOV', 'DEC']
        dd = date & 0xff
        mm = (date & 0xff00) >> 8
        yy = ((date & 0xff0000) >> 16) + 1900
        return "%02d-%s-%d" % (dd, months[mm], yy)

def int2time(time):
        """Convert the AIPS catalog time value to a string."""
        # Time is of the form 0xHHMMSS
        ss = time & 0xff
        mm = (time & 0xff00) >> 8
        hh = (time & 0xff0000) >> 16
        return "%02d:%02d:%02d" % (hh, mm, ss)

def read_struct(infile, format):
	struct_size = struct.calcsize(format)
	return struct.unpack(format, infile.read(struct_size))

def seek_rec(infile, taskname):
	infile.seek(0)
	blocks, tasks, date, time, res = read_struct(infile, header)
	found = False
	for i in range(tasks):
		name, date, time, version = read_struct(infile, dir_entry)
		if name.strip() == taskname.upper():
			found = True
			break
	if not found:
		raise IndexError
	infile.seek(4096 * (i+1) + 2088) # or maybe 1024 * res * (i+1) + 2088
	return vname[version]

def print_directory(infile):
	infile.seek(0)
	blocks, tasks, date, time, res = read_struct(infile, header)
	for i in range(tasks):
		name, date, time, version = read_struct(infile, dir_entry)
		print name, int2date(date), int2time(time), vname[version]
	
def trim_str(var):
	if type(var) == list:
		for i in range(len(var)):
			var[i] = trim_str(var[i])
	else:
		if type(var) == str:
			var = var.strip()
	return var

def trim_list(var):
	for i in range(len(var)):
		if type(var[i]) == str:
			continue
		elif hasattr(var[i], '__getitem__'):
			var[i] = trim_list(var[i])
	for i in range(len(var)-1, 1, -1):
		if var[i] == 0 or var[i] == '' or var[i] == [None, 0.0]:
			del var[i]
	return var

def read_adverb(params, file, adverb, value=None):
        """Read (sub)value for adverb ADVERB from TD file FILE."""
	# Copied from ParselTongue Proxy.AIPSTask, slightly modified

        # We use the default value for type checks.
        if value == None:
            value = params.default_dict[adverb]

        if type(value) == float:
            (value,) = struct.unpack('f', file.read(4))
        elif type(value) == str:
            strlen = ((params.strlen_dict[adverb] + 3) // 4) * 4
            fmt = "%ds" % strlen
            (value,) = struct.unpack(fmt, file.read(strlen))
            value.strip()
        elif type(value) == list:
            newvalue = [None]
            for subvalue in value[1:]:
                subvalue = read_adverb(params, file, adverb, subvalue)
                newvalue.append(subvalue)
                continue
            value = newvalue
        else:
            raise AssertionError, type(value)
        return value

if __name__ == '__main__':
	if len(sys.argv) < 2 or len(sys.argv) > 3:
		print >> sys.stderr, 'Usage: %s <userid> [task]' % sys.argv[0]
		sys.exit(1)
	
	try:
		userid = int(sys.argv[1])
	except ValueError:
		print >> sys.stderr, 'Invalid userno: %s' % sys.argv[1]
		sys.exit(1)
	inf = open(filename % ehex(userid, 3, 0))

	if len(sys.argv) == 3:
		taskname = sys.argv[2]
	else: 
		print_directory(inf)
		sys.exit(0)

	try:
		vname = seek_rec(inf, taskname)
		version = os.environ[vname].split('/')[-1]
	except IndexError:
		print >> sys.stderr, 'Task not found'
		sys.exit(0)
	
	params = _AIPSTaskParams(taskname, version)
	inputs = params.input_list
	defaults = params.default_dict
	
	set_adverbs = {}
	for adverb in inputs:
		output = trim_str(read_adverb(params, inf, adverb))
		if output != defaults[adverb]:
			# Store non-default adverbs only
			if type(output) == str:
				#print quotes
				output = "'" + output + "'"
			elif hasattr(output, '__getitem__'):
				#if adverb is an array, delete trailing empty values
				output = trim_list(output)
			set_adverbs[adverb] = output
	
	# Print ParselTongue code for task execution
	print '# Version is %s %s' % (version, vname)
	print "%s = AIPSTask('%s')" % (taskname, taskname)
	for adverb in inputs:
		if adverb in set_adverbs:
			print '%s.%s =' % (taskname, adverb), set_adverbs[adverb]
	print '%s.go()' % taskname
